==> eks-1.93.0-sources.jar: software/amazon/awscdk/services/eks/EksOptimizedImageProps.java <==
package software.amazon.awscdk.services.eks;

/**
 * Properties for EksOptimizedImage.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:47:08.072Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.eks.$Module.class, fqn = "@aws-cdk/aws-eks.EksOptimizedImageProps")
@software.amazon.jsii.Jsii.Proxy(EksOptimizedImageProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface EksOptimizedImageProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * What cpu architecture to retrieve the image for (arm64 or x86_64).
     * <p>
     * Default: CpuArch.X86_64
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.eks.CpuArch getCpuArch() {
        return null;
    }

    /**
     * The Kubernetes version to use.
     * <p>
     * Default: - The latest version
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getKubernetesVersion() {
        return null;
    }

    /**
     * What instance type to retrieve the image for (standard or GPU-optimized).
     * <p>
     * Default: NodeType.STANDARD
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.eks.NodeType getNodeType() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link EksOptimizedImageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link EksOptimizedImageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<EksOptimizedImageProps> {
        private software.amazon.awscdk.services.eks.CpuArch cpuArch;
        private java.lang.String kubernetesVersion;
        private software.amazon.awscdk.services.eks.NodeType nodeType;

        /**
         * Sets the value of {@link EksOptimizedImageProps#getCpuArch}
         * @param cpuArch What cpu architecture to retrieve the image for (arm64 or x86_64).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cpuArch(software.amazon.awscdk.services.eks.CpuArch cpuArch) {
            this.cpuArch = cpuArch;
            return this;
        }

        /**
         * Sets the value of {@link EksOptimizedImageProps#getKubernetesVersion}
         * @param kubernetesVersion The Kubernetes version to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder kubernetesVersion(java.lang.String kubernetesVersion) {
            this.kubernetesVersion = kubernetesVersion;
            return this;
        }

        /**
         * Sets the value of {@link EksOptimizedImageProps#getNodeType}
         * @param nodeType What instance type to retrieve the image for (standard or GPU-optimized).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder nodeType(software.amazon.awscdk.services.eks.NodeType nodeType) {
            this.nodeType = nodeType;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EksOptimizedImageProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public EksOptimizedImageProps build() {
            return new Jsii$Proxy(cpuArch, kubernetesVersion, nodeType);
        }
    }

    /**
     * An implementation for {@link EksOptimizedImageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements EksOptimizedImageProps {
        private final software.amazon.awscdk.services.eks.CpuArch cpuArch;
        private final java.lang.String kubernetesVersion;
        private final software.amazon.awscdk.services.eks.NodeType nodeType;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cpuArch = software.amazon.jsii.Kernel.get(this, "cpuArch", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.eks.CpuArch.class));
            this.kubernetesVersion = software.amazon.jsii.Kernel.get(this, "kubernetesVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.nodeType = software.amazon.jsii.Kernel.get(this, "nodeType", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.eks.NodeType.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.eks.CpuArch cpuArch, final java.lang.String kubernetesVersion, final software.amazon.awscdk.services.eks.NodeType nodeType) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cpuArch = cpuArch;
            this.kubernetesVersion = kubernetesVersion;
            this.nodeType = nodeType;
        }

        @Override
        public final software.amazon.awscdk.services.eks.CpuArch getCpuArch() {
            return this.cpuArch;
        }

        @Override
        public final java.lang.String getKubernetesVersion() {
            return this.kubernetesVersion;
        }

        @Override
        public final software.amazon.awscdk.services.eks.NodeType getNodeType() {
            return this.nodeType;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCpuArch() != null) {
                data.set("cpuArch", om.valueToTree(this.getCpuArch()));
            }
            if (this.getKubernetesVersion() != null) {
                data.set("kubernetesVersion", om.valueToTree(this.getKubernetesVersion()));
            }
            if (this.getNodeType() != null) {
                data.set("nodeType", om.valueToTree(this.getNodeType()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-eks.EksOptimizedImageProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            EksOptimizedImageProps.Jsii$Proxy that = (EksOptimizedImageProps.Jsii$Proxy) o;

            if (this.cpuArch != null ? !this.cpuArch.equals(that.cpuArch) : that.cpuArch != null) return false;
            if (this.kubernetesVersion != null ? !this.kubernetesVersion.equals(that.kubernetesVersion) : that.kubernetesVersion != null) return false;
            return this.nodeType != null ? this.nodeType.equals(that.nodeType) : that.nodeType == null;
        }

        @Override
        public final int hashCode() {
            int result = this.cpuArch != null ? this.cpuArch.hashCode() : 0;
            result = 31 * result + (this.kubernetesVersion != null ? this.kubernetesVersion.hashCode() : 0);
            result = 31 * result + (this.nodeType != null ? this.nodeType.hashCode() : 0);
            return result;
        }
    }
}

==> eks-1.182.0-sources.jar: software/amazon/awscdk/services/eks/EksOptimizedImageProps.java <==
package software.amazon.awscdk.services.eks;

/**
 * Properties for EksOptimizedImage.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.eks.*;
 * EksOptimizedImageProps eksOptimizedImageProps = EksOptimizedImageProps.builder()
 *         .cpuArch(CpuArch.ARM_64)
 *         .kubernetesVersion("kubernetesVersion")
 *         .nodeType(NodeType.STANDARD)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:46.698Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.eks.$Module.class, fqn = "@aws-cdk/aws-eks.EksOptimizedImageProps")
@software.amazon.jsii.Jsii.Proxy(EksOptimizedImageProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface EksOptimizedImageProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * What cpu architecture to retrieve the image for (arm64 or x86_64).
     * <p>
     * Default: CpuArch.X86_64
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.eks.CpuArch getCpuArch() {
        return null;
    }

    /**
     * The Kubernetes version to use.
     * <p>
     * Default: - The latest version
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getKubernetesVersion() {
        return null;
    }

    /**
     * What instance type to retrieve the image for (standard or GPU-optimized).
     * <p>
     * Default: NodeType.STANDARD
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.eks.NodeType getNodeType() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link EksOptimizedImageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link EksOptimizedImageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<EksOptimizedImageProps> {
        software.amazon.awscdk.services.eks.CpuArch cpuArch;
        java.lang.String kubernetesVersion;
        software.amazon.awscdk.services.eks.NodeType nodeType;

        /**
         * Sets the value of {@link EksOptimizedImageProps#getCpuArch}
         * @param cpuArch What cpu architecture to retrieve the image for (arm64 or x86_64).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cpuArch(software.amazon.awscdk.services.eks.CpuArch cpuArch) {
            this.cpuArch = cpuArch;
            return this;
        }

        /**
         * Sets the value of {@link EksOptimizedImageProps#getKubernetesVersion}
         * @param kubernetesVersion The Kubernetes version to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder kubernetesVersion(java.lang.String kubernetesVersion) {
            this.kubernetesVersion = kubernetesVersion;
            return this;
        }

        /**
         * Sets the value of {@link EksOptimizedImageProps#getNodeType}
         * @param nodeType What instance type to retrieve the image for (standard or GPU-optimized).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder nodeType(software.amazon.awscdk.services.eks.NodeType nodeType) {
            this.nodeType = nodeType;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EksOptimizedImageProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public EksOptimizedImageProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link EksOptimizedImageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements EksOptimizedImageProps {
        private final software.amazon.awscdk.services.eks.CpuArch cpuArch;
        private final java.lang.String kubernetesVersion;
        private final software.amazon.awscdk.services.eks.NodeType nodeType;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cpuArch = software.amazon.jsii.Kernel.get(this, "cpuArch", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.eks.CpuArch.class));
            this.kubernetesVersion = software.amazon.jsii.Kernel.get(this, "kubernetesVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.nodeType = software.amazon.jsii.Kernel.get(this, "nodeType", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.eks.NodeType.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cpuArch = builder.cpuArch;
            this.kubernetesVersion = builder.kubernetesVersion;
            this.nodeType = builder.nodeType;
        }

        @Override
        public final software.amazon.awscdk.services.eks.CpuArch getCpuArch() {
            return this.cpuArch;
        }

        @Override
        public final java.lang.String getKubernetesVersion() {
            return this.kubernetesVersion;
        }

        @Override
        public final software.amazon.awscdk.services.eks.NodeType getNodeType() {
            return this.nodeType;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCpuArch() != null) {
                data.set("cpuArch", om.valueToTree(this.getCpuArch()));
            }
            if (this.getKubernetesVersion() != null) {
                data.set("kubernetesVersion", om.valueToTree(this.getKubernetesVersion()));
            }
            if (this.getNodeType() != null) {
                data.set("nodeType", om.valueToTree(this.getNodeType()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-eks.EksOptimizedImageProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            EksOptimizedImageProps.Jsii$Proxy that = (EksOptimizedImageProps.Jsii$Proxy) o;

            if (this.cpuArch != null ? !this.cpuArch.equals(that.cpuArch) : that.cpuArch != null) return false;
            if (this.kubernetesVersion != null ? !this.kubernetesVersion.equals(that.kubernetesVersion) : that.kubernetesVersion != null) return false;
            return this.nodeType != null ? this.nodeType.equals(that.nodeType) : that.nodeType == null;
        }

        @Override
        public final int hashCode() {
            int result = this.cpuArch != null ? this.cpuArch.hashCode() : 0;
            result = 31 * result + (this.kubernetesVersion != null ? this.kubernetesVersion.hashCode() : 0);
            result = 31 * result + (this.nodeType != null ? this.nodeType.hashCode() : 0);
            return result;
        }
    }
}
